pub enum ErrorKind {
BadRequest,
Unauthorized,
Forbidden,
NotFound,
MethodNotAllowed,
Conflict,
PayloadTooLarge,
Unprocessable,
TooManyRequests,
Internal,
ServiceUnavailable,
GatewayTimeout,
}Expand description
The category of an Error, which determines the HTTP status code.
Variants
BadRequest
400 Bad Request.
401 Unauthorized.
Forbidden
403 Forbidden.
NotFound
404 Not Found.
MethodNotAllowed
405 Method Not Allowed.
Conflict
409 Conflict.
PayloadTooLarge
413 Payload Too Large.
Unprocessable
422 Unprocessable Entity.
TooManyRequests
429 Too Many Requests.
Internal
500 Internal Server Error.
503 Service Unavailable.
GatewayTimeout
504 Gateway Timeout.
Implementations
Sourceimpl ErrorKind
impl ErrorKind
Sourcepub fn status(self) -> StatusCode
pub fn status(self) -> StatusCode
Returns the HTTP status code for this error category.
Sourcepub fn code(self) -> &'static str
pub fn code(self) -> &'static str
Returns the default stable, machine-readable code for this category.
Codes are upper snake case (for example NOT_FOUND). An Error may
override this with a more specific code via Error::with_code.