pub struct LoggerConfig { /* private fields */ }Expand description
How the application logs.
Implementations
Sourceimpl LoggerConfig
impl LoggerConfig
Sourcepub fn level(self, level: impl Into<String>) -> Self
pub fn level(self, level: impl Into<String>) -> Self
Sets the maximum log level (trace/debug/info/warn/error, or any
RUST_LOG-style directive).
Sourcepub fn service_name(self, name: impl Into<String>) -> Self
pub fn service_name(self, name: impl Into<String>) -> Self
Sets the service name reported in structured logs.
Sourcepub fn error_detail(self, detail: ErrorLogDetail) -> Self
pub fn error_detail(self, detail: ErrorLogDetail) -> Self
Sets how much error detail structured log records include.
Sourcepub fn request_logs(self, enabled: bool) -> Self
pub fn request_logs(self, enabled: bool) -> Self
Enables or disables the automatic HTTP request-completed log.
Sourcepub fn include_source(self, include: bool) -> Self
pub fn include_source(self, include: bool) -> Self
Includes the source file and line in each record.
Sourcepub fn include_thread_ids(self, include: bool) -> Self
pub fn include_thread_ids(self, include: bool) -> Self
Includes the thread id in each record.
Sourcepub fn non_blocking(self, non_blocking: bool) -> Self
pub fn non_blocking(self, non_blocking: bool) -> Self
Writes through a non-blocking background worker.
Sourcepub fn file(self, file: FileLogConfig) -> Self
pub fn file(self, file: FileLogConfig) -> Self
Adds a rolling file sink.
Sourcepub fn telemetry(self, telemetry: TelemetryConfig) -> Self
pub fn telemetry(self, telemetry: TelemetryConfig) -> Self
Adds OpenTelemetry trace export (effective with the otel feature).