pub struct Matcher { /* private fields */ }Expand description
Compiled, per-method path matcher over a flat route table.
Implementations
Sourceimpl Matcher
impl Matcher
Sourcepub fn build(routes: Vec<Route>) -> Result<Self>
pub fn build(routes: Vec<Route>) -> Result<Self>
Builds a matcher from fully-qualified routes.
Errors
Returns an internal error if a route path is not a valid pattern or if the same method and path are registered twice.