pub struct TestRequestBuilder { /* private fields */ }Expand description
Builds and sends a single HTTP request.
Created by the verb methods on TestClient
(get/post/…). Set headers, query parameters, and a body, then call
send.
Implementations
Sourceimpl TestRequestBuilder
impl TestRequestBuilder
Sourcepub fn header(self, name: &str, value: &str) -> Self
pub fn header(self, name: &str, value: &str) -> Self
Adds a request header. An invalid name or value is ignored.
Sourcepub fn unsafe_header(self, name: &str, value: &str) -> Self
pub fn unsafe_header(self, name: &str, value: &str) -> Self
Adds a security-sensitive request header, bypassing the in-process guard.
Sourcepub fn form<T: Serialize>(self, value: &T) -> Self
pub fn form<T: Serialize>(self, value: &T) -> Self
Sets a urlencoded form body (application/x-www-form-urlencoded).
Sourcepub fn bytes(self, bytes: impl Into<Bytes>) -> Self
pub fn bytes(self, bytes: impl Into<Bytes>) -> Self
Sets a raw byte body, with no content type unless one is set via header.
Sourcepub fn multipart(self) -> TestMultipartBuilder
pub fn multipart(self) -> TestMultipartBuilder
Switches to a multipart/form-data body builder.
Sourcepub async fn send(self) -> Result<TestResponse>
pub async fn send(self) -> Result<TestResponse>
Sends the request and returns the response.
Sourcepub async fn sse(self) -> Result<TestSseStream>
pub async fn sse(self) -> Result<TestSseStream>
Sends the request and reads the response as a Server-Sent Events stream.