pub struct Route { /* private fields */ }Expand description
A single route: an HTTP method, a path pattern, a handler, and metadata.
The path is local to the router that owns the route until the router tree
is flattened, at which point enclosing prefixes are prepended.
Implementations
Sourceimpl Route
impl Route
Sourcepub fn new(method: Method, path: impl Into<String>, handler: HandlerFn) -> Self
pub fn new(method: Method, path: impl Into<String>, handler: HandlerFn) -> Self
Creates a route for method at the local path, served by handler.
Sourcepub fn on_request<F, Fut>(self, hook: F) -> Self
pub fn on_request<F, Fut>(self, hook: F) -> Self
Registers a scoped, observe-only on_request hook.
Scoped hooks run in addition to the app-global ones, after routing.
Sourcepub fn on_response<F, Fut>(self, hook: F) -> Self
pub fn on_response<F, Fut>(self, hook: F) -> Self
Registers a scoped, observe-only on_response hook.
Sourcepub fn on_error<F, Fut>(self, hook: F) -> Self
pub fn on_error<F, Fut>(self, hook: F) -> Self
Registers a scoped, observe-only on_error hook (non-validation errors).
Sourcepub fn on_validation_error<F, Fut>(self, hook: F) -> Self
pub fn on_validation_error<F, Fut>(self, hook: F) -> Self
Registers a scoped, observe-only on_validation_error hook.
Sourcepub fn description(self, description: impl Into<String>) -> Self
pub fn description(self, description: impl Into<String>) -> Self
Sets the operation description.
Sourcepub fn status_code(self, status_code: StatusCode) -> Self
pub fn status_code(self, status_code: StatusCode) -> Self
Sets the default success status code.
Sourcepub fn response_model<T: ?Sized>(self) -> Self
pub fn response_model<T: ?Sized>(self) -> Self
Records the response model type name for documentation.
Sourcepub fn request_schema<T: JsonSchema>(self) -> Self
pub fn request_schema<T: JsonSchema>(self) -> Self
Records the request body schema generator.
Sourcepub fn request_schema_fn(self, thunk: SchemaThunk) -> Self
pub fn request_schema_fn(self, thunk: SchemaThunk) -> Self
Records the request body schema generator from a thunk (for form bodies).
Sourcepub fn request_kind(self, kind: RequestBodyKind) -> Self
pub fn request_kind(self, kind: RequestBodyKind) -> Self
Sets the request body encoding (application/json by default).
Sourcepub fn response_schema<T: JsonSchema>(self) -> Self
pub fn response_schema<T: JsonSchema>(self) -> Self
Records the success response body schema generator.
Sourcepub fn streaming(self) -> Self
pub fn streaming(self) -> Self
Marks the response as a stream (documented as text/event-stream).
Sourcepub fn websocket(self) -> Self
pub fn websocket(self) -> Self
Marks the route as a WebSocket endpoint (documented as an AsyncAPI channel).
Sourcepub fn ws_incoming<T: JsonSchema>(self) -> Self
pub fn ws_incoming<T: JsonSchema>(self) -> Self
Records the schema of messages the WebSocket receives.
Sourcepub fn ws_outgoing<T: JsonSchema>(self) -> Self
pub fn ws_outgoing<T: JsonSchema>(self) -> Self
Records the schema of messages the WebSocket sends.